@@ -1,8 +1,7 @@
 import sys
 from pathlib import Path
-
-import click
 from ruamel.yaml import YAML
+from rich import print
 
 from qube.lint.TemplateLinter import TemplateLinter
 from qube.lint.domains.cli import CliJavaLint
@@ -12,9 +11,11 @@ from qube.lint.domains.portlet import PortletGroovyLint
 from qube.lint.domains.service import ServiceJavaLint
 
 
-def lint_project(project_dir: str) -> TemplateLinter:
+def lint_project(project_dir: str, is_create: bool = False) -> TemplateLinter:
     """
-    Verifies the integrity of a project to best coding standards and practices.
+    Verifies the integrity of a project to best coding and practices.
+    Runs a set of general linting functions, which all templates share and afterwards runs template specific linting functions.
+    All results are collected and presented to the user.
     """
     # Detect which template the project is based on
     template_handle = get_template_handle(project_dir)
@@ -27,26 +28,28 @@ def lint_project(project_dir: str) -> TemplateLinter:
         'portlet-groovy': PortletGroovyLint
     }
 
-    lint_obj = switcher.get(template_handle, lambda: 'Invalid')(project_dir)
+    try:
+        lint_obj = switcher.get(template_handle)(project_dir)
+    except TypeError:
+        print(f'[bold red]Unable to find linter for handle {template_handle}! Aborting...')
+        sys.exit(1)
+
     # Run the linting tests
     try:
-        # Disable check files? Some templates use their very own set of files, which do not adhere to QBiC's common files standards.
-        disable_check_files_templates = []
-        if template_handle in disable_check_files_templates:
-            disable_check_files = True
-        else:
-            disable_check_files = False
-
         # Run non project specific linting
-        click.echo(click.style('Running general linting', fg='blue'))
-        lint_obj.lint_project(super(lint_obj.__class__, lint_obj), label='General Linting', custom_check_files=disable_check_files)
+        print('[bold blue]Running general linting')
+        lint_obj.lint_project(super(lint_obj.__class__, lint_obj), is_subclass_calling=False)
 
         # Run the project specific linting
-        click.echo(click.style(f'Running {template_handle} linting', fg='blue'))
-        lint_obj.lint(f'{template_handle} Linting')
+        print(f'[bold blue]Running {template_handle} linting')
+
+        # for every python project that is created autopep8 will run one time
+        # when linting en existing python qube project, autopep8 should be now optional,
+        # because (for example) it messes up Jinja syntax (if included in project)
+        lint_obj.lint()
     except AssertionError as e:
-        click.echo(click.style(f'Critical error: {e}', fg='red'))
-        click.echo(click.style('Stopping tests...', fg='red'))
+        print(f'[bold red]Critical error: {e}')
+        print('[bold red] Stopping tests...')
         return lint_obj
 
     # Print the results
@@ -54,18 +57,19 @@ def lint_project(project_dir: str) -> TemplateLinter:
 
     # Exit code
     if len(lint_obj.failed) > 0:
-        click.echo(click.style('Sorry, some tests failed - exiting with a non-zero error code...\n'))
+        print(f'[bold red] {len(lint_obj.failed)} tests failed! Exiting with non-zero error code.')
+        sys.exit(1)
 
 
 def get_template_handle(dot_qube_path: str = '.qube.yml') -> str:
     """
     Reads the .qube file and extracts the template handle
-    :param dot_qube_path: path to the .qube.yml file
+    :param dot_qube_path: path to the .qube file
     :return: found template handle
     """
     path = Path(f'{dot_qube_path}/.qube.yml')
     if not path.exists():
-        click.echo(click.style('.qube.yml not found. Is this a QUBE project?', fg='red'))
+        print('[bold red].qube.yml not found. Is this a qube project?')
         sys.exit(1)
     yaml = YAML(typ='safe')
     dot_qube_content = yaml.load(path)
